
import React, { useState, useEffect, useRef } from 'react';
import ReactDOM from 'react-dom';
import { GoogleGenAI, Chat } from "@google/genai";

// SVG Icons for the UI
const ChatIcon = () => (
  <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round">
    <path d="M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z"></path>
  </svg>
);
const SendIcon = () => (
  <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round">
    <line x1="22" y1="2" x2="11" y2="13"></line><polygon points="22 2 15 22 11 13 2 9 22 2"></polygon>
  </svg>
);
const CloseIcon = () => <>&#x2715;</>;

interface Message {
  id: string;
  text: string;
  sender: 'user' | 'bot';
}

const App = () => {
  const [isOpen, setIsOpen] = useState(false);
  const [messages, setMessages] = useState<Message[]>([
    {
      id: 'initial-message',
      text: "Xin chào! Tôi là trợ lý AI tư vấn tuyển sinh của Trường Đại học Vinh. Tôi có thể giúp gì cho bạn?",
      sender: 'bot'
    }
  ]);
  const [inputValue, setInputValue] = useState('');
  const [isLoading, setIsLoading] = useState(false);
  const chatRef = useRef<Chat | null>(null);
  const messagesEndRef = useRef<HTMLDivElement | null>(null);

  useEffect(() => {
    // Initialize the chat instance
    const ai = new GoogleGenAI({ apiKey: process.env.API_KEY });
    chatRef.current = ai.chats.create({
      model: 'gemini-2.5-flash-preview-04-17',
      config: {
          systemInstruction: `Bạn là một trợ lý AI tư vấn tuyển sinh cho Trường Đại học Vinh. Nhiệm vụ của bạn là trả lời các câu hỏi của thí sinh và phụ huynh về các ngành học, học phí, thủ tục nhập học, và các thông tin liên quan đến tuyển sinh của trường. Luôn trả lời bằng tiếng Việt một cách thân thiện, chính xác và chuyên nghiệp.

Dưới đây là cơ sở tri thức về Trường Đại học Vinh để bạn sử dụng khi trả lời:

**THÔNG TIN CHUNG:**
- **Tên trường:** Trường Đại học Vinh (Vinh University).
- **Địa chỉ chính:** Số 182, đường Lê Duẩn, thành phố Vinh, tỉnh Nghệ An.
- **Lịch sử:** Thành lập năm 1959, là trường đại học trọng điểm quốc gia.
- **Tầm nhìn:** Trở thành đại học thông minh, top 500 châu Á vào năm 2030, top 1000 thế giới vào năm 2045.
- **Sứ mạng:** Đào tạo nhân lực chất lượng cao, dẫn dắt sự phát triển giáo dục khu vực Bắc Trung Bộ.
- **Giá trị cốt lõi:** Trung thực, Trách nhiệm, Say mê, Sáng tạo, Hợp tác.
- **Quy mô:** Gần 35.000 học sinh, sinh viên. Hơn 1.000 cán bộ, giảng viên với 50 GS/PGS và 300 Tiến sĩ.
- **Đào tạo:** 57 ngành đại học, 38 chuyên ngành thạc sĩ, 17 chuyên ngành tiến sĩ.
- **Cơ sở vật chất:** 5 cơ sở, KTX cho hơn 4.200 sinh viên, thư viện lớn, hệ thống phòng học, phòng thí nghiệm hiện đại.

**BAN GIÁM HIỆU:**
1.  **Hiệu trưởng: GS.TS. Nguyễn Huy Bằng**
    -   Email: bangnh@vinhuni.edu.vn
    -   Điện thoại: 0238.3733888
    -   Nhiệm vụ: Quản lý toàn diện, phụ trách các mặt công tác trọng yếu như chiến lược, tổ chức cán bộ, đào tạo đại học chính quy.
2.  **Phó Hiệu trưởng: PGS.TS. Trần Bá Tiến**
    -   Email: tientb@vinhuni.edu.vn
    -   Điện thoại: 0238.3855452
    -   Nhiệm vụ: Phụ trách đào tạo Sau đại học, hợp tác quốc tế, hoạt động các trường trực thuộc (THPT Chuyên, Tiểu học...).
3.  **Phó Hiệu trưởng: PGS.TS. Nguyễn Thị Thu Cúc**
    -   Email: cucntt@vinhuni.edu.vn
    -   Điện thoại: 0238.3855452
    -   Nhiệm vụ: Phụ trách công tác tài chính, công tác sinh viên, cơ sở vật chất, quan hệ doanh nghiệp.

Khi có người hỏi về thông tin liên hệ, hãy cung cấp thông tin của người phù hợp với lĩnh vực họ quan tâm. Ví dụ, nếu hỏi về sau đại học, hãy ưu tiên cung cấp thông tin của PGS.TS. Trần Bá Tiến.`,
      },
    });
  }, []);
  
  useEffect(() => {
    messagesEndRef.current?.scrollIntoView({ behavior: 'smooth' });
  }, [messages, isLoading]);

  const handleSendMessage = async () => {
    if (inputValue.trim() === '' || !chatRef.current || isLoading) return;

    const userMessage: Message = { id: `user-${Date.now()}`, text: inputValue, sender: 'user' };
    setMessages(prev => [...prev, userMessage]);
    setInputValue('');
    setIsLoading(true);

    try {
      const stream = await chatRef.current.sendMessageStream({ message: inputValue });
      
      let botMessageId = `bot-${Date.now()}`;
      let currentText = '';
      setMessages(prev => [...prev, { id: botMessageId, text: '', sender: 'bot' }]);

      for await (const chunk of stream) {
        currentText += chunk.text;
        setMessages(prev => prev.map(msg => 
          msg.id === botMessageId ? { ...msg, text: currentText } : msg
        ));
      }
    } catch (error) {
      console.error("Error sending message:", error);
      const errorMessage: Message = { id: `err-${Date.now()}`, text: "Xin lỗi, đã có lỗi xảy ra. Vui lòng thử lại sau.", sender: 'bot'};
      setMessages(prev => [...prev, errorMessage]);
    } finally {
      setIsLoading(false);
    }
  };

  const handleKeyPress = (e: React.KeyboardEvent<HTMLInputElement>) => {
    if (e.key === 'Enter') {
      handleSendMessage();
    }
  };

  return (
    <>
      <div className={`chat-widget-container ${isOpen ? 'open' : 'closed'}`}>
        <div className="chat-header">
          <h3>Tư vấn tuyển sinh ĐH Vinh</h3>
          <button className="close-button" onClick={() => setIsOpen(false)} aria-label="Close Chat">
            &mdash;
          </button>
        </div>
        <div className="chat-body">
          {messages.map((msg) => (
            <div key={msg.id} className={`message ${msg.sender}`}>
              {msg.sender === 'bot' && <div className="avatar">V</div>}
              <div className="text">{msg.text}</div>
            </div>
          ))}
          {isLoading && messages[messages.length-1].sender === 'user' && (
             <div className="message bot">
               <div className="avatar">V</div>
               <div className="text typing-indicator">
                 <span></span><span></span><span></span>
               </div>
             </div>
          )}
          <div ref={messagesEndRef} />
        </div>
        <div className="chat-input">
          <input
            type="text"
            value={inputValue}
            onChange={(e) => setInputValue(e.target.value)}
            onKeyPress={handleKeyPress}
            placeholder="Nhập câu hỏi của bạn..."
            aria-label="Chat input"
            disabled={isLoading}
          />
          <button onClick={handleSendMessage} disabled={!inputValue.trim() || isLoading} aria-label="Send Message">
            <SendIcon />
          </button>
        </div>
      </div>
      {!isOpen && (
        <button className="chat-toggle-button" onClick={() => setIsOpen(true)} aria-label="Open Chat">
          <ChatIcon />
        </button>
      )}
    </>
  );
};

ReactDOM.render(<App />, document.getElementById('root'));
